# Official EODHD APIs Python Library
https://eodhd.com

## Installation

    python3 -m pip install eodhd

## Note

Demo API key below is provided by EOD Historial Data for testing purposes
<https://eodhd.com/financial-apis/new-real-time-data-api-websockets?utm_source=github&utm_medium=eod&utm_campaign=python_lib>

## Sample code and examples

The files below contain examples of available functions

* example_api.py - describes the functions that can be used in the apiclient file (APIClient class)
* example_scanner.py - describes the functions that can be used in the apiclient file (ScannerClient class)
* example_websockets.py - describes the functions that can be used in the websocketclient file (WebSocketClient class)

New features will be added to the example files. The most relevant functions can be viewed directly in the code files.
